@@ -411,15 +411,11 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     
     
     #Add insight text
-    #For Actionable Features
-    #change_score['insight'] = np.where(change_score['binary'] == False,
-    #                                   "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+" will increase the score by "+round(change_score['effect']*100,1).astype(str)+" percentage points."
-    #                                   ) 
-    
-    #Remove "by step_jump" and change "by percentag_point percentage points" to increase relative to current score
+    #For Actionable Features    
+    #Remove "by step_jump" and make to increase relative to current score
     change_score['insight'] = np.where(change_score['binary'] == False,
-                                       change_score['direction']+" \'"+change_score['feature_label']+f"\' will increase {dv_description} by "+(change_score['effect_pct']*100).astype(int).astype(str)+"%.",
-                                       "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+(change_score['effect_pct']*100).astype(int).astype(str)+"%."
+                                       change_score['direction']+" \'"+change_score['feature_label']+f"\' will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", (change_score['effect_pct']*100).astype(int).astype(str)+"%."),
+                                       "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", (change_score['effect_pct']*100).astype(int).astype(str)+"%.")
                                        )     
     
     #For Explainable (not-Actionable) Features
