@@ -22,7 +22,7 @@ def split_data(df, train_pct=0.7, dv=None, dv_threshold=0.0, random_state=5435):
         x_train, x_test, y_train, y_test = train_test_split(x, 
                                                             y, 
                                                             train_size=train_pct, 
-                                                            test_size=1 - train_pct, 
+                                                            test_size=np.round(1 - train_pct,3), 
                                                             random_state=random_state, 
                                                             shuffle=True)
 
